package com.ruoyi.system.mapper;

import java.util.List;

import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.system.domain.SysGzReport;
import com.ruoyi.system.domain.SysGzReportControl;
import org.apache.ibatis.annotations.Param;

/**
 * 工资上报控制Mapper接口
 * 
 * @author ruoyi
 * @date 2021-05-24
 */
public interface SysGzReportControlMapper 
{
    /**
     * 查询工资上报控制
     * 
     * @param id 工资上报控制ID
     * @return 工资上报控制
     */
    public SysGzReportControl selectSysGzReportControlById(Long id);

    /**
     * 查询工资上报控制列表
     * 
     * @param sysGzReportControl 工资上报控制
     * @return 工资上报控制集合
     */
    public List<SysGzReportControl> selectSysGzReportControlList(SysGzReportControl sysGzReportControl);

    /**
     * 查询 上报情况
     * @param deptId
     * @param reportYear
     * @return
     */
    public List<SysGzReportControl> selectSysGzReportByDeptId(@Param("deptId") Long deptId, @Param("reportYear") int reportYear);

    /**
     * 查询 上报情况
     * @param reportCode 报送编码
     * @return
     */
    //public SysGzReportControl selectSysGzReportControlByReportCode(@Param("reportCode")String reportCode);

    /**
     * @param reportCode 报送编码
     * @param reportType 报送类型
     * @param reportCode
     * @param reportType
     * @return
     */
    public SysGzReportControl selectSysGzReportControlByCodeAndType(@Param("reportCode")String reportCode, @Param("reportType")String reportType);


    /**
     * 查询 报送 年份 数组
     * @return
     */
    public List<String> selectReportYear();

    /**
     * 校验报送编码是否唯一
     *
     * @param reportCode 报送编码
     * @return 结果
     */
    public int checkReportCodeUnique(@Param("reportCode") String reportCode, @Param("reportType") String reportType);

    /**
     * 统计 应报送数
     * @return
     */
    public int queryTotalNum(SysGzReport sysGzReport);


    /**
     * 统计未报送数
     * @param sysGzReport
     * @return
     */
    public int queryNoReportNum(SysGzReport sysGzReport);

    /** 统计报送数
     *
     * @param sysGzReport
     * @return
     */
    public int queryReportNum(SysGzReport sysGzReport);

    /**
     * 统计 应报送数
     * @return
     */
    public List<SysGzReport> queryTotalList(SysGzReport sysGzReport);

    /**
     * 统计未报送数
     * @param sysGzReport
     * @return
     */
    public List<SysGzReport> queryNoReportList(SysGzReport sysGzReport);

    /**
     * 新增工资上报控制
     * 
     * @param sysGzReportControl 工资上报控制
     * @return 结果
     */
    public int insertSysGzReportControl(SysGzReportControl sysGzReportControl);

    /**
     * 修改工资上报控制
     * 
     * @param sysGzReportControl 工资上报控制
     * @return 结果
     */
    public int updateSysGzReportControl(SysGzReportControl sysGzReportControl);

    /**
     * 删除工资上报控制
     * 
     * @param id 工资上报控制ID
     * @return 结果
     */
    public int deleteSysGzReportControlById(Long id);

    /**
     * 批量删除工资上报控制
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteSysGzReportControlByIds(Long[] ids);
}
