package com.ruoyi.system.mapper;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.system.domain.SysGzReportEmploye;
import com.ruoyi.system.domain.SysGzReportEmployeHistory;
import org.apache.ibatis.annotations.Param;

/**
 * 员工花名册Mapper接口
 * 
 * @author ruoyi
 * @date 2021-06-11
 */
public interface SysGzReportEmployeMapper 
{
    /**
     * 查询员工花名册
     * 
     * @param employeId 员工花名册ID
     * @return 员工花名册
     */
    public SysGzReportEmploye selectSysGzReportEmployeById(Long employeId);

    /**
     * 员工身份证号
     *
     * @param idCardNo 员工身份证号
     * @return 员工花名册
     */
    public SysGzReportEmploye selectSysGzReportEmployeByIdCard(String idCardNo);

    /**
     * 员工唯一码
     *
     * @param uniqueCode 员工唯一码
     * @return 员工花名册
     */
    public SysGzReportEmploye selectSysGzReportEmployeByUniqueCode(String uniqueCode);


    /**
     * 查询员工花名册
     * @param deptId 部门ID
     * @param name   员工姓名
     * @return
     */
    public SysGzReportEmploye selectSysGzReportEmployeByName(@Param("deptId")Long deptId, @Param("name")String name);

    /**
     * 查询员工是否调动
     * @param employeId 员工ID
     * @param deptId 部门ID
     * @return
     */
    public SysGzReportEmployeHistory checkIsTransfer(@Param("employeId") Long employeId, @Param("deptId") Long deptId);

    /**
     * 查询员工花名册列表
     * 
     * @param sysGzReportEmploye 员工花名册
     * @return 员工花名册集合
     */
    public List<SysGzReportEmploye> selectSysGzReportEmployeList(SysGzReportEmploye sysGzReportEmploye);

    /**
     * 查询历史记录
     * @param sysGzReportEmploye
     * @return
     */
    public SysGzReportEmploye selectEmployeHistiryLastOne(SysGzReportEmploye sysGzReportEmploye);

    /**
     * 查询未上报工资信息的员工
     * @param deptId
     * @param reportCode
     * @return
     */
    public List<SysGzReportEmploye> selectNotReportList(@Param("deptId")Long deptId, @Param("reportCode")String reportCode);

    /**
     * 查询员工花名册列表
     *
     * @param sysGzReportEmploye 员工花名册
     * @return 员工花名册集合
     */
    public List<SysGzReportEmploye> selectSysGzReportEmployeListApply(SysGzReportEmploye sysGzReportEmploye);

    /**
     * 查询员工花名册列表
     *
     * @param sysGzReportEmploye 员工花名册
     * @return 员工花名册集合
     */
    public List<SysGzReportEmploye> selectSysGzReportEmployeListApprove(SysGzReportEmploye sysGzReportEmploye);

    /**
     * 统计员工花名册
     *
     * @param dept 部门名称
     * @return 员工花名册集合
     */
    public List<Map<String,Object>> selectEmployeStatistics(SysDept dept);

    /**
     * 新增员工花名册
     * 
     * @param sysGzReportEmploye 员工花名册
     * @return 结果
     */
    public int insertSysGzReportEmploye(SysGzReportEmploye sysGzReportEmploye);

    /**
     * 复制一条数据到历史库
     */
    public int replicateOne(@Param("employeId")Long employeId,@Param("replicateBy")String replicateBy ,@Param("approveType")String approveType);

    /**
     * 花名册快照，每月1日定时快照
     */
    public int snapshotEmploye(@Param("dateCode")String dateCode);

    /**
     * 修改员工花名册
     * 
     * @param sysGzReportEmploye 员工花名册
     * @return 结果
     */
    public int updateSysGzReportEmploye(SysGzReportEmploye sysGzReportEmploye);

    /**
     * 删除员工花名册
     * 
     * @param employeId 员工花名册ID
     * @return 结果
     */
    public int deleteSysGzReportEmployeById(Long employeId);

    /**
     * 批量删除员工花名册
     * 
     * @param employeIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteSysGzReportEmployeByIds(Long[] employeIds);
}
