package com.ruoyi.system.mapper;

import java.util.List;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.system.domain.ReprotSummaryInfo;
import com.ruoyi.system.domain.SysGzReportEmploye;
import com.ruoyi.system.domain.SysGzReportInfo;
import com.ruoyi.system.domain.vo.WagesParams;
import org.apache.ibatis.annotations.Param;

/**
 * 工资上报详情Mapper接口
 * 
 * @author ruoyi
 * @date 2021-05-24
 */
public interface SysGzReportInfoMapper 
{
    /**
     * 查询工资上报详情
     * 
     * @param id 工资上报详情ID
     * @return 工资上报详情
     */
    public SysGzReportInfo selectSysGzReportInfoById(Long id);

    /**
     * 通过 姓名 查询 数据是否存在
     * @param reportId   报送ID
     * @param employeId  员工ID
     * @return
     */
    public SysGzReportInfo selectByCodeAndEmployeId(@Param("reportId")Long reportId, @Param("employeId")Long employeId);

    /**
     * 查询工资上报详情列表
     * 
     * @param sysGzReportInfo 工资上报详情
     * @return 工资上报详情集合
     */
    public List<SysGzReportInfo> selectSysGzReportInfoList(SysGzReportInfo sysGzReportInfo);

    /**
     * 查询工资上报详情列表
     *
     * @param employe 综合查询
     * @return 工资上报详情集合
     */
    public List<SysGzReportInfo> selectList(SysGzReportEmploye employe);

    /**
     * 统计全年人数和工资
     * @param deptId
     * @return
     */
    public List<ReprotSummaryInfo> selectSummaryListByDeptId(@Param("deptId")Long deptId, @Param("year")int year);

    /**
     * 统计全年人数和工资
     * @param deptId
     * @return
     */
    public int selectIncreaseNum(@Param("deptId") Long deptId, @Param("reportCode") String reportCode, @Param("lastReportCode") String lastReportCode);

    /**
     * 统计全年人数和工资
     * @param deptId
     * @return
     */
    public int selectDecreaseNum(@Param("deptId") Long deptId, @Param("reportCode") String reportCode, @Param("lastReportCode") String lastReportCode);

    /**
     * 统计全年人数和工资
     * @param wages
     * @return
     */
    public List<ReprotSummaryInfo> selectSummaryListByPostLevel(WagesParams wages);

    /**
     * 统计全年人数和工资
     * @param wages
     * @return
     */
    public List<ReprotSummaryInfo> selectSummaryListByPostTitle(WagesParams wages);


    /**
     * 新增工资上报详情
     * 
     * @param sysGzReportInfo 工资上报详情
     * @return 结果
     */
    public int insertSysGzReportInfo(SysGzReportInfo sysGzReportInfo);

    /**
     * 修改工资上报详情
     * 
     * @param sysGzReportInfo 工资上报详情
     * @return 结果
     */
    public int updateSysGzReportInfo(SysGzReportInfo sysGzReportInfo);

    /**
     * 删除工资上报详情
     * 
     * @param id 工资上报详情ID
     * @return 结果
     */
    public int deleteSysGzReportInfoById(Long id);

    /**
     * 批量删除工资上报详情
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteSysGzReportInfoByIds(Long[] ids);

    /**
     * 删除 工资上报详情
     *
     * @param reportId 报送ID
     * @return 结果
     */
    public int deleteSysGzReportInfoByReportId(Long reportId);
}
